@@ -1,19 +1,3 @@
-// This file is part of the shakmaty-syzygy library.
-// Copyright (C) 2017-2021 Niklas Fiekas <niklas.fiekas@backscattering.de>
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-
 use std::{fs, io, marker::PhantomData, path::Path};
 
 use arrayvec::ArrayVec;
@@ -66,6 +50,7 @@ impl TableTag for DtzTag {
 
 bitflags! {
     /// Table layout flags.
+    #[derive(Debug)]
     struct Layout: u8 {
         /// Two sided table for non-symmetrical material configuration.
         const SPLIT = 1;
@@ -76,6 +61,7 @@ bitflags! {
 
 bitflags! {
     /// Subtable format flags.
+    #[derive(Debug)]
     struct Flag: u8 {
         /// DTZ table stores black to move.
         const STM = 1;
@@ -144,7 +130,7 @@ const MULT_TWIST: [u64; 64] = [
 /// overflow in debug mode.
 const Z0: u64 = u64::max_value();
 
-/// Encoding of all 461 configurations of two not-connected kings.
+/// Encoding of all 462 configurations of two not-connected kings.
 #[rustfmt::skip]
 const KK_IDX: [[u64; 64]; 10] = [[
      Z0,  Z0,  Z0,   0,   1,   2,   3,   4,
@@ -649,10 +635,9 @@ impl PairsData {
         if flags.contains(Flag::SINGLE_VALUE) {
             let single_value = if T::METRIC == Metric::Wdl {
                 raf.read_u8_at(ptr + 1)?
-            } else if S::CAPTURES_COMPULSORY {
-                1 // http://www.talkchess.com/forum/viewtopic.php?p=698093#698093
             } else {
-                0
+                // http://www.talkchess.com/forum/viewtopic.php?p=698093#698093
+                u8::from(S::CAPTURES_COMPULSORY)
             };
 
             return Ok((
@@ -823,6 +808,7 @@ impl<T: TableTag, S: Position + Syzygy, F: ReadAt> Table<T, S, F> {
     ///
     /// Panics if the `material` configuration is not supported by Syzygy
     /// tablebases (more than 7 pieces or side without pieces).
+    #[track_caller]
     pub fn new(raf: F, material: &Material) -> ProbeResult<Table<T, S, F>> {
         let material = material.clone();
         assert!(material.count() <= MAX_PIECES);
@@ -885,7 +871,7 @@ impl<T: TableTag, S: Position + Syzygy, F: ReadAt> Table<T, S, F> {
                     ],
                 ];
 
-                ptr += 1 + if pp { 1 } else { 0 };
+                ptr += 1 + u64::from(pp);
 
                 let sides = [Color::White, Color::Black]
                     .iter()
@@ -1220,9 +1206,9 @@ impl<T: TableTag, S: Position + Syzygy, F: ReadAt> Table<T, S, F> {
             }
 
             if self.num_unique_pieces > 2 {
-                let adjust1 = if squares[1] > squares[0] { 1 } else { 0 };
-                let adjust2 = if squares[2] > squares[0] { 1 } else { 0 }
-                    + if squares[2] > squares[1] { 1 } else { 0 };
+                let adjust1 = u64::from(squares[1] > squares[0]);
+                let adjust2 =
+                    u64::from(squares[2] > squares[0]) + u64::from(squares[2] > squares[1]);
 
                 if offdiag(squares[0]) {
                     TRIANGLE[usize::from(squares[0])] * 63 * 62
@@ -1250,7 +1236,7 @@ impl<T: TableTag, S: Position + Syzygy, F: ReadAt> Table<T, S, F> {
                 }
             } else if self.num_unique_pieces == 2 {
                 if S::CONNECTED_KINGS {
-                    let adjust = if squares[1] > squares[0] { 1 } else { 0 };
+                    let adjust = u64::from(squares[1] > squares[0]);
 
                     if offdiag(squares[0]) {
                         TRIANGLE[usize::from(squares[0])] * 63 + (u64::from(squares[1]) - adjust)
