@@ -1,19 +1,3 @@
-// This file is part of the shakmaty-syzygy library.
-// Copyright (C) 2017-2021 Niklas Fiekas <niklas.fiekas@backscattering.de>
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-
 use std::{
     cmp::{max, Reverse},
     fs, io,
@@ -70,7 +54,10 @@ impl<S: Position + Clone + Syzygy> Tablebase<S> {
         }
     }
 
-    /// Returns the maximum number of pieces of any added table.
+    /// Returns the maximum number of pieces over all added tables.
+    ///
+    /// This number is updated when adding table files and very fast to read.
+    #[inline]
     pub fn max_pieces(&self) -> usize {
         self.max_pieces
     }
@@ -122,15 +109,14 @@ impl<S: Position + Clone + Syzygy> Tablebase<S> {
             return Err(io::Error::from(io::ErrorKind::InvalidInput));
         }
 
-        let (stem, ext) = match (path.file_stem().and_then(|s| s.to_str()), path.extension()) {
-            (Some(stem), Some(ext)) => (stem, ext),
-            _ => return Err(io::Error::from(io::ErrorKind::InvalidInput)),
-        };
+        let (stem, ext) = path
+            .file_stem()
+            .and_then(|s| s.to_str())
+            .zip(path.extension())
+            .ok_or_else(|| io::Error::from(io::ErrorKind::InvalidInput))?;
 
-        let material = match Material::from_str(stem) {
-            Ok(material) => material,
-            _ => return Err(io::Error::from(io::ErrorKind::InvalidInput)),
-        };
+        let material =
+            Material::from_str(stem).map_err(|_| io::Error::from(io::ErrorKind::InvalidInput))?;
 
         let pieces = material.count();
 
@@ -161,7 +147,7 @@ impl<S: Position + Clone + Syzygy> Tablebase<S> {
     }
 
     fn wdl_table(&self, key: &Material) -> SyzygyResult<&WdlTable<S, RandomAccessFile>> {
-        if let Some(&(ref path, ref table)) = self
+        if let Some((path, table)) = self
             .wdl
             .get(key)
             .or_else(|| self.wdl.get(&key.clone().into_flipped()))
@@ -178,7 +164,7 @@ impl<S: Position + Clone + Syzygy> Tablebase<S> {
     }
 
     fn dtz_table(&self, key: &Material) -> SyzygyResult<&DtzTable<S, RandomAccessFile>> {
-        if let Some(&(ref path, ref table)) = self
+        if let Some((path, table)) = self
             .dtz
             .get(key)
             .or_else(|| self.dtz.get(&key.clone().into_flipped()))
