@@ -1,19 +1,3 @@
-// This file is part of the shakmaty-syzygy library.
-// Copyright (C) 2017-2021 Niklas Fiekas <niklas.fiekas@backscattering.de>
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-
 use std::{convert::TryFrom, fmt, ops::Neg};
 
 use arrayvec::ArrayVec;
@@ -70,7 +54,6 @@ impl Syzygy for Chess {
 }
 
 #[cfg(feature = "variant")]
-#[cfg_attr(docs_rs, doc(cfg(feature = "variant")))]
 impl Syzygy for shakmaty::variant::Atomic {
     const TBW: TableType = TableType {
         ext: "atbw",
@@ -87,7 +70,6 @@ impl Syzygy for shakmaty::variant::Atomic {
 }
 
 #[cfg(feature = "variant")]
-#[cfg_attr(docs_rs, doc(cfg(feature = "variant")))]
 impl Syzygy for shakmaty::variant::Antichess {
     const TBW: TableType = TableType {
         ext: "gtbw",
@@ -169,8 +151,7 @@ impl<T> MaybeRounded<T> {
     /// Gets the inner value.
     pub fn ignore_rounding(self) -> T {
         match self {
-            MaybeRounded::Rounded(v) => v,
-            MaybeRounded::Precise(v) => v,
+            MaybeRounded::Rounded(v) | MaybeRounded::Precise(v) => v,
         }
     }
 
@@ -414,29 +395,20 @@ impl AmbiguousWdl {
         }
     }
 
-    /// Converts `dtz` to a WDL value. `MaybeRounded::Rounded(Dtz(100))`
-    /// and `MaybeRounded::Rounded(Dtz(-100))` are
-    /// [ambiguous due to DTZ rounding](MaybeRounded)
-    /// and will be mapped to [`AmbiguousWdl::MaybeWin`] and
-    /// [`AmbiguousWdl::MaybeLoss`] respectively.
-    pub(crate) fn from_dtz(dtz: MaybeRounded<Dtz>) -> AmbiguousWdl {
-        match dtz {
-            MaybeRounded::Rounded(Dtz(100)) => AmbiguousWdl::MaybeWin,
-            MaybeRounded::Rounded(Dtz(-100)) => AmbiguousWdl::MaybeLoss,
-            MaybeRounded::Precise(dtz) | MaybeRounded::Rounded(dtz) => Wdl::from_dtz(dtz).into(),
-        }
-    }
-
     /// Gets the WDL value for a position with the given `dtz` and `halfmoves`
     /// counter.
     ///
     /// The value will always be unambiguous if `halfmoves == 0`.
     pub fn from_dtz_and_halfmoves(dtz: MaybeRounded<Dtz>, halfmoves: u32) -> AmbiguousWdl {
-        if halfmoves == 0 {
-            AmbiguousWdl::from(Wdl::from_dtz_after_zeroing(dtz))
+        AmbiguousWdl::from(if halfmoves == 0 {
+            Wdl::from_dtz_after_zeroing(dtz)
         } else {
-            AmbiguousWdl::from_dtz(dtz.add_plies_saturating(halfmoves))
-        }
+            match dtz.add_plies_saturating(halfmoves) {
+                MaybeRounded::Rounded(Dtz(100)) => return AmbiguousWdl::MaybeWin,
+                MaybeRounded::Rounded(Dtz(-100)) => return AmbiguousWdl::MaybeLoss,
+                MaybeRounded::Precise(dtz) | MaybeRounded::Rounded(dtz) => Wdl::from_dtz(dtz),
+            }
+        })
     }
 
     /// Get the unambiguous [`Wdl`], assuming that the value has been reached
@@ -549,6 +521,7 @@ impl Dtz {
     /// assert_eq!(Dtz(0).add_plies(3), Dtz(0));
     /// assert_eq!(Dtz(-1).add_plies(3), Dtz(-4));
     /// ```
+    #[track_caller]
     #[must_use]
     pub fn add_plies(self, plies: u32) -> Dtz {
         self.add_plies_checked(plies).expect("dtz overflow")
